@@ -11,18 +11,18 @@ def alpha_geodesic(
     $\alpha$-geodesic between two probability distributions
     """
 
-    a += 1e-12
-    b += 1e-12
+    a_ = a + 1e-12
+    b_ = b + 1e-12
     if alpha == 1:
-        return torch.exp((1 - lmd) * torch.log(a) + lmd * torch.log(b))
+        return torch.exp((1 - lmd) * torch.log(a_) + lmd * torch.log(b_))
     elif alpha >= 1e+9:
         return torch.min(a, b)
     elif alpha <= -1e+9:
         return torch.max(a, b)
     else:
         p = (1 - alpha) / 2
-        lhs = a ** p
-        rhs = b ** p
+        lhs = a_ ** p
+        rhs = b_ ** p
         g = ((1 - lmd) * lhs + lmd * rhs) ** (1/p)
 
         if alpha > 0 and (g == 0).sum() > 0:
